﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using Infragistics.Controls.Maps;
using Infragistics.DragDrop;


namespace WpfApplication1
{
    /// <summary>
    /// Lógica de interacción para MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            this.Loaded += MainWindow_Loaded;
            this.chart.NodeControlAttachedEvent += chart_NodeControlAttachedEvent;
            this.chart.NodeMouseDoubleClick += chart_NodeMouseDoubleClick;
        }

        void chart_NodeMouseDoubleClick(object sender, OrgChartNodeClickEventArgs e)
        {
            this.FillChart();
        }

        void MainWindow_Loaded(object sender, RoutedEventArgs e)
        {
            this.FillChart();
        }

        void chart_NodeControlAttachedEvent(object sender, OrgChartNodeEventArgs e)
        {
            object data = e.Node.Node.Data;
            MyNode myNode = data as MyNode;
            
            DragSource dragSource = new DragSource();
            dragSource.IsDraggable = true;
            dragSource.Drop += dragSource_Drop;
            dragSource.DragChannels.Add("CHANNEL");
            DragDropManager.SetDragSource(e.Node, dragSource);
        

            DropTarget dropTarget = new DropTarget();
            dropTarget.IsDropTarget = true;
            dropTarget.DropChannels.Add("CHANNEL");
            DragDropManager.SetDropTarget(e.Node, dropTarget);
            
        }

        void dragSource_Drop(object sender, DropEventArgs e)
        {
            OrgChartNodeControl source = e.DragSource as OrgChartNodeControl;
            OrgChartNodeControl target = e.DropTarget as OrgChartNodeControl;

            MyNode sourceNode = (MyNode)source.Node.Data;
            MyNode targetNode = (MyNode)source.Node.Data;

            string s = string.Format("You dragged {0} over {1}", sourceNode.Description, targetNode.Description);
            MessageBox.Show(s);
        }

        private void FillChart()
        {
            MyNode root = new MyNode() { Description = "ROOT" };

            List<MyNode> nodesInLevel = new List<MyNode>();
            nodesInLevel.Add(root);

            Random rnd = new Random();
            this.AddChilds(root, 0, 2, rnd);

            List<MyNode> myNodes = new List<MyNode>();
            myNodes.Add(root);
            this.chart.ItemsSource = myNodes;
        }

        private void AddChilds(MyNode parent, int level, int maxLevel, Random rnd)
        {            
            int numberOfChilds = rnd.Next(6);
            for (int i = 0; i < numberOfChilds; i++)
            {
                MyNode child = new MyNode();
                child.Description = string.Format("Node {0} in level {1}", i, level);
                parent.ChildNodes.Add(child);

                if (level < maxLevel)                                    
                    this.AddChilds(child, level + 1, maxLevel, rnd);                
            }
        }

        private void cFill_Click(object sender, RoutedEventArgs e)
        {
            this.FillChart();
        }
    }
}
